@@ -11,7 +11,7 @@ our ($VERSION);
 use XSLoader ();
 
 BEGIN {
-    $VERSION = '0.13_01';
+    $VERSION = '0.15_01';
     XSLoader::load();
 }
 
@@ -25,7 +25,7 @@ CBOR::Free - Fast CBOR for everyone
 
 =head1 SYNOPSIS
 
-    $cbor = CBOR::Free::encode( $scalar_or_ar_or_hr );
+    $cbor = CBOR::Free::encode( $some_data_structure );
 
     $thing = CBOR::Free::decode( $cbor )
 
@@ -61,9 +61,25 @@ The encoder currently does not handle any other blessed references.
 
 =over
 
-=item * C<canonical> - A boolean that makes the function output
+=item * C<canonical> - A boolean that makes the encoder output
 CBOR in L<canonical form|https://tools.ietf.org/html/rfc7049#section-3.9>.
 
+=item * C<preserve_references> - A boolean that makes the encoder encode
+multi-referenced values via L<CBOR’s “shared references” tags|https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml>. This allows encoding of shared
+and circular references. It also incurs a performance penalty.
+
+(Take care that any circular references in your application don’t cause
+memory leaks!)
+
+=item * C<scalar_references> - A boolean that makes the encoder accept
+scalar references
+(rather than reject them) and encode them via
+L<CBOR’s “indirection” tag|https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml>.
+Most languages don’t use references as Perl does, so this option seems of
+little use outside all-Perl IPC contexts; it is arguably more useful, then,
+for general use to have the encoder reject data structures that most other
+languages cannot represent.
+
 =back
 
 Notes on mapping Perl to CBOR:
@@ -74,11 +90,19 @@ Notes on mapping Perl to CBOR:
 integer, float, byte string, or character string) determines its CBOR
 encoding.
 
+=item * Perl hash keys become CBOR binary strings.
+
 =item * L<Types::Serialiser> booleans are encoded as CBOR booleans.
 Perl undef is encoded as CBOR null. (NB: No Perl value encodes as CBOR
 undefined.)
 
-=item * Scalar references are encoded via L<CBOR’s “indirection” tag|https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml>.
+=item * Scalar references (including references to other references) are
+unhandled by default, which makes them trigger an exception. You can
+optionally tell CBOR::Free to encode them via the C<scalar_references> flag.
+
+=item * Via the optional C<preserve_references> flag, circular and shared
+references may be preserved. Without this flag, circular references cause an
+exception, and other shared references are not preserved.
 
 =item * Instances of L<CBOR::Free::Tagged> are encoded as tagged values.
 
@@ -108,7 +132,11 @@ An exception is thrown if the decoder finds anything else as a map key.
 =item * CBOR booleans become the corresponding L<Types::Serialiser> values.
 Both CBOR null and undefined become Perl undef.
 
-=item * L<CBOR’s “indirection” tag|https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml> is interpreted as a scalar reference.
+=item * L<CBOR’s “indirection” tag|https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml> is interpreted as a scalar reference. This behavior is always
+active; unlike with the encoder, there is no need to enable it manually.
+
+=item * C<preserve_references()> mode complements the same flag
+given to the encoder.
 
 =item * This function does not interpret any other tags. If you need to
 decode other tags, look at L<CBOR::Free::Decoder>. Any unhandled tags that
@@ -131,11 +159,12 @@ convenience aliases for the equivalent L<Types::Serialiser> functions.
 =head1 FRACTIONAL (FLOATING-POINT) NUMBERS
 
 Floating-point numbers are encoded in CBOR as IEEE 754 half-, single-,
-or double-precision. If your Perl is compiled to use “long double”
-floating-point numbers, you may see rounding errors when converting
-to/from CBOR. If that’s a problem for you, append an empty string to
-your floating-point numbers, which will cause CBOR::Free to encode
-them as strings.
+or double-precision. If your Perl is compiled to use anything besides
+IEEE 754 double-precision to represent floating-point values (e.g.,
+“long double” or “quadmath” compilation options), you may see rounding
+errors when converting to/from CBOR. If that’s a problem for you, append
+an empty string to your floating-point numbers, which will cause CBOR::Free
+to encode them as strings.
 
 =head1 INTEGER LIMITS
 
